package cn.iocoder.yudao.module.partner.mapper;


import cn.iocoder.yudao.module.partner.entity.PartnerCustomerInfo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 客户信息Mapper接口
 *
 * @author zcy
 * @date 2023-09-13
 */
@Mapper
public interface PartnerCustomerInfoMapper extends BaseMapper<PartnerCustomerInfo>
{
    /**
     * 查询客户信息列表
     *
     * @param partnerCustomerInfo 客户信息
     * @return 客户信息集合
     */
    public List<PartnerCustomerInfo> selectPartnerCustomerInfoList(@Param("vo") PartnerCustomerInfo vo);

    IPage<PartnerCustomerInfo> pagePartnerCustomerInfoList(@Param("vo") PartnerCustomerInfo vo, Page<PartnerCustomerInfo> page);

    /**
     * 查询客户信息
     *
     * @param id 客户信息主键
     * @return 客户信息
     */
    public PartnerCustomerInfo selectPartnerCustomerInfoById(Long id);

    int insertPartnerCustomerInfo(PartnerCustomerInfo partnerCustomerInfo);

    /**
     * 修改客户信息
     *
     * @param partnerCustomerInfo 客户信息
     * @return 结果
     */
    public int updatePartnerCustomerInfo(PartnerCustomerInfo partnerCustomerInfo);

    /**
     * 批量删除客户信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePartnerCustomerInfoByIds(Long[] ids);


}
